ActorArtboard class

Implementers

Constructors

ActorArtboard(Actor actor)

Properties

actor → Actor
no setter
animations → List<ActorAnimation>
no setter
clipContents → bool
no setter
componentCount → int
no setter
components → List<ActorComponent?>
no setter
drawableNodes → List<ActorDrawable>
no setter
drawNodeCount → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
no setter
modulateOpacity ↔ double
getter/setter pair
name → String
no setter
nodeCount → int
no setter
nodes → List<ActorNode?>
no setter
origin → Vec2D
no setter
overrideColor ↔ Float32List?
getter/setter pair
root → ActorNode
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translation → Vec2D
no setter
width → double
no setter

Methods

addDependency(ActorComponent a, ActorComponent b) → bool
addDirt(ActorComponent component, int value, bool recurse) → bool
advance(double seconds) → void
artboardAABB() → AABB
completeResolveHierarchy() → void
computeAABB() → AABB?
copyArtboard(ActorArtboard artboard) → void
getAnimation(String name) → ActorAnimation?
getNode<T extends ActorNode>(String name) → T?
initializeGraphics() → void
makeInstance() → ActorArtboard
makeInstanceWithActor(Actor actor) → ActorArtboard
markDrawOrderDirty() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(StreamReader reader) → void
readAnimationsBlock(StreamReader block) → void
readComponentsBlock(StreamReader block) → void
resolveHierarchy() → void
sortDependencies() → void
sortDrawOrder() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → ActorComponent?